@@ -100,3 +100,46 @@ WORKSPACE_CREATE_COPY_GET_REQUEST_RESPONSE = {
 WORKSPACE_RESPONSE_JSON = [{"key": "value"}]
 
 SAMPLE_QUERY = "SELECT * FROM sc_data_lake.features_singlecell LIMIT 100"
+
+MOCKED_DICT_RESPONSE = {
+    "data": [
+        {
+            "repo_id": "1687428192072",
+            "repo_name": "new_omix_for_refac_3",
+            "indexes": {},
+            "v2_indexes": {},
+            "sources": [],
+            "datatypes": [],
+            "dataset_count": 0,
+            "disease_count": 0,
+            "tissue_count": 0,
+            "organism_count": 0,
+            "cell_line_count": 0,
+            "cell_type_count": 0,
+            "drug_count": 0,
+            "data_type_count": 0,
+            "data_source_count": 0,
+            "sample_count": 0,
+            "normal_sample_count": 0,
+        },
+        {
+            "repo_id": "1687428145396",
+            "repo_name": "new_omix_for_refac_2",
+            "indexes": {},
+            "v2_indexes": {},
+            "sources": [],
+            "datatypes": [],
+            "dataset_count": 0,
+            "disease_count": 0,
+            "tissue_count": 0,
+            "organism_count": 0,
+            "cell_line_count": 0,
+            "cell_type_count": 0,
+            "drug_count": 0,
+            "data_type_count": 0,
+            "data_source_count": 0,
+            "sample_count": 0,
+            "normal_sample_count": 0,
+        },
+    ]
+}
